summaryrefslogtreecommitdiffstats
path: root/qt/qextscintilla.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:00 -0600
commit6ade7e598a18691f3f92471c4441d856b3ac54dc (patch)
treeca18ed733e273279bab574978806068e506c241a /qt/qextscintilla.h
parent5e3fc3a36b58c4e1cb48e31a350f76b7a81b3170 (diff)
downloadtqscintilla-6ade7e598a18691f3f92471c4441d856b3ac54dc.tar.gz
tqscintilla-6ade7e598a18691f3f92471c4441d856b3ac54dc.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 5e3fc3a36b58c4e1cb48e31a350f76b7a81b3170.
Diffstat (limited to 'qt/qextscintilla.h')
-rw-r--r--qt/qextscintilla.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/qt/qextscintilla.h b/qt/qextscintilla.h
index 331ebad..c34c88d 100644
--- a/qt/qextscintilla.h
+++ b/qt/qextscintilla.h
@@ -920,10 +920,10 @@ public slots:
//! If any lines are currently folded then they are all unfolded.
//! Otherwise all lines are folded. This has the same effect as
//! clicking in the fold margin with the shift and control keys
//! pressed. If \a children is not set (the default) then only the top
//! level fold points are affected, otherwise the state of all fold
//! points are changed.
- virtual void foldAll(bool children = FALSE);
+ virtual void foldAll(bool tqchildren = FALSE);
//! If the line \a line is folded then it is unfolded. Otherwise it is
//! folded. This has the same effect as clicking in the fold margin.
@@ -920,10 +920,10 @@ public slots:
//! Otherwise all lines are folded. This has the same effect as
//! clicking in the fold margin with the shift and control keys
- //! pressed. If \a children is not set (the default) then only the top
+ //! pressed. If \a tqchildren is not set (the default) then only the top
//! level fold points are affected, otherwise the state of all fold
//! points are changed.